@@ -19,11 +19,12 @@
 
 package org.apache.myfaces.tobago.config;
 
-import org.apache.myfaces.tobago.application.ProjectStage;
 import org.apache.myfaces.tobago.context.Theme;
 import org.apache.myfaces.tobago.internal.config.ContentSecurityPolicy;
+import org.apache.myfaces.tobago.internal.config.SecurityAnnotation;
 import org.apache.myfaces.tobago.sanitizer.Sanitizer;
 
+import javax.faces.application.ProjectStage;
 import javax.faces.context.FacesContext;
 import javax.servlet.ServletContext;
 import java.util.List;
@@ -41,32 +42,44 @@ public abstract class TobagoConfig {
     return (TobagoConfig) servletContext.getAttribute(TOBAGO_CONFIG);
   }
 
-  public abstract Theme getTheme(final String name);
+  public abstract Theme getTheme(String name);
 
   public abstract List<Theme> getSupportedThemes();
 
   public abstract Theme getDefaultTheme();
 
+  /**
+   * @deprecated since 4.0.0, use {@link javax.faces.application.Application#getProjectStage}
+   */
+  @Deprecated
   public abstract ProjectStage getProjectStage();
 
   public abstract boolean isCreateSessionSecret();
 
   public abstract boolean isCheckSessionSecret();
 
+  /**
+   * @deprecated But needed to support frame security in IE11. Is replaced by CSP "frame-ancestors".
+   */
+  @Deprecated
   public abstract boolean isPreventFrameAttacks();
 
   public abstract ContentSecurityPolicy getContentSecurityPolicy();
 
   public abstract boolean isSetNosniffHeader();
 
+  public abstract SecurityAnnotation getSecurityAnnotation();
+
   public abstract Sanitizer getSanitizer();
 
-  public abstract boolean isAutoAccessKeyFromLabel();
+  public abstract boolean isDecodeLineFeed();
 
   public abstract Map<String, String> getMimeTypes();
 
   /**
-   * For backward compatibility. The default is false.
+   * @return false
+   * @deprecated since Tobago 3.0.0
    */
+  @Deprecated
   public abstract boolean isClassicDateTimePicker();
 }
