@@ -19,7 +19,10 @@
 
 package org.apache.myfaces.tobago.internal.component;
 
-public abstract class AbstractUIColumnSelector extends AbstractUIColumn {
+/**
+ * {@link org.apache.myfaces.tobago.internal.taglib.component.ColumnSelectorTagDeclaration}
+ */
+public abstract class AbstractUIColumnSelector extends AbstractUIColumnBase {
 
 /* TBD
   @Override
@@ -28,8 +31,5 @@ public abstract class AbstractUIColumnSelector extends AbstractUIColumn {
   }
 */
 
-  @Override
-  public String getLabel() {
-    return null;
-  }
+  public abstract boolean isDisabled();
 }
